==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCamera_FrameRateRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qcamera.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCamera_FrameRateRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCamera::FrameRateRange")
    QCamera::FrameRateRange *_ptr = reinterpret_cast<QCamera::FrameRateRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new FrameRateRange()
void __qt_construct_QCamera_FrameRateRange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FrameRateRange()")
    Q_UNUSED(__java_arguments)
    QCamera::FrameRateRange *__qt_this = new(__qtjambi_ptr) QCamera::FrameRateRange();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new FrameRateRange(qreal,qreal)
void __qt_construct_QCamera_FrameRateRange_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FrameRateRange(qreal,qreal)")
    jdouble minimum0 = __java_arguments[0].d;
    Q_UNUSED(minimum0)
    jdouble maximum1 = __java_arguments[1].d;
    Q_UNUSED(maximum1)
    QCamera::FrameRateRange *__qt_this = new(__qtjambi_ptr) QCamera::FrameRateRange(static_cast<qreal>(minimum0), static_cast<qreal>(maximum1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCamera::FrameRateRange
void __qt_destruct_QCamera_FrameRateRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCamera::FrameRateRange")
    reinterpret_cast<QCamera::FrameRateRange*>(ptr)->~FrameRateRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCamera::FrameRateRange::FrameRateRange()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_initialize_1native__Lio_qt_multimedia_QCamera_00024FrameRateRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCamera::FrameRateRange::FrameRateRange()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCamera_FrameRateRange_0, sizeof(QCamera::FrameRateRange), typeid(QCamera::FrameRateRange), false, &deleter_QCamera_FrameRateRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCamera::FrameRateRange::FrameRateRange(qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_initialize_1native__Lio_qt_multimedia_QCamera_00024FrameRateRange_2DD)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble minimum0,
 jdouble maximum1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCamera::FrameRateRange::FrameRateRange(qreal,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].d = minimum0;
        arguments[1].d = maximum1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCamera_FrameRateRange_1, sizeof(QCamera::FrameRateRange), typeid(QCamera::FrameRateRange), false, &deleter_QCamera_FrameRateRange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCamera::FrameRateRange::operator==(QCamera::FrameRateRange,QCamera::FrameRateRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_equals_1native_1cref_1QCamera_1FrameRateRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID r21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCamera::FrameRateRange::operator==(QCamera::FrameRateRange,QCamera::FrameRateRange)", __qt_this)
        const QCamera::FrameRateRange& __qt_r21 = QtJambiAPI::valueReferenceFromNativeId<QCamera::FrameRateRange>(r21);
        __java_return_value = (*__qt_this) == __qt_r21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_setMaximumFrameRate_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble maximumFrameRate0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->maximumFrameRate = static_cast<qreal>(maximumFrameRate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_maximumFrameRate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->maximumFrameRate;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_setMinimumFrameRate_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble minimumFrameRate0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->minimumFrameRate = static_cast<qreal>(minimumFrameRate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_minimumFrameRate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->minimumFrameRate;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCamera_FrameRateRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCamera::FrameRateRange>("QCamera::FrameRateRange", "io/qt/multimedia/QCamera$FrameRateRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCamera_FrameRateRange, {
        ConstructorInfo(&__qt_construct_QCamera_FrameRateRange_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCamera_FrameRateRange_1, "DD")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCamera_FrameRateRange);
    registerMetaType<QCamera::FrameRateRange>("QCamera::FrameRateRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCamera_FrameRateRange_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qcamera.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCamera_FrameRateRange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCamera::FrameRateRange")
    QCamera::FrameRateRange *_ptr = reinterpret_cast<QCamera::FrameRateRange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new FrameRateRange()
void __qt_construct_QCamera_FrameRateRange(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FrameRateRange()")
    Q_UNUSED(__java_arguments)
    QCamera::FrameRateRange *__qt_this = new(__qtjambi_ptr) QCamera::FrameRateRange();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCamera::FrameRateRange::FrameRateRange()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_initialize_1native__Lio_qt_multimedia_QCamera_00024FrameRateRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCamera::FrameRateRange::FrameRateRange()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCamera_FrameRateRange, sizeof(QCamera::FrameRateRange), typeid(QCamera::FrameRateRange), false, &deleter_QCamera_FrameRateRange, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FrameRateRange(QCamera::FrameRateRange)
void __qt_construct_QCamera_FrameRateRange_cref_QCamera_FrameRateRange(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FrameRateRange(QCamera::FrameRateRange)")
    jobject other0 = __java_arguments[0].l;
    const QCamera::FrameRateRange& __qt_other0 = qtjambi_cast<const QCamera::FrameRateRange& >(__jni_env, other0);
    QCamera::FrameRateRange *__qt_this = new(__qtjambi_ptr) QCamera::FrameRateRange(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCamera::FrameRateRange::FrameRateRange(QCamera::FrameRateRange)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_initialize_1native__Lio_qt_multimedia_QCamera_00024FrameRateRange_2Lio_qt_multimedia_QCamera_00024FrameRateRange_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCamera::FrameRateRange::FrameRateRange(QCamera::FrameRateRange)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCamera_FrameRateRange_cref_QCamera_FrameRateRange, sizeof(QCamera::FrameRateRange), typeid(QCamera::FrameRateRange), false, &deleter_QCamera_FrameRateRange, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FrameRateRange(qreal,qreal)
void __qt_construct_QCamera_FrameRateRange_qreal_qreal(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FrameRateRange(qreal,qreal)")
    jdouble minimum0 = __java_arguments[0].d;
    Q_UNUSED(minimum0)
    jdouble maximum1 = __java_arguments[1].d;
    Q_UNUSED(maximum1)
    QCamera::FrameRateRange *__qt_this = new(__qtjambi_ptr) QCamera::FrameRateRange(static_cast<qreal>(minimum0), static_cast<qreal>(maximum1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCamera::FrameRateRange::FrameRateRange(qreal,qreal)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_initialize_1native__Lio_qt_multimedia_QCamera_00024FrameRateRange_2DD)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble minimum0,
 jdouble maximum1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCamera::FrameRateRange::FrameRateRange(qreal,qreal)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].d = minimum0;
        arguments[1].d = maximum1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCamera_FrameRateRange_qreal_qreal, sizeof(QCamera::FrameRateRange), typeid(QCamera::FrameRateRange), false, &deleter_QCamera_FrameRateRange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCamera::FrameRateRange
void __qt_destruct_QCamera_FrameRateRange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCamera::FrameRateRange")
    reinterpret_cast<QCamera::FrameRateRange*>(ptr)->~FrameRateRange();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCamera::FrameRateRange::operator==(QCamera::FrameRateRange,QCamera::FrameRateRange)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_equals_1native_1cref_1QCamera_1FrameRateRange__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID r21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCamera::FrameRateRange::operator==(QCamera::FrameRateRange,QCamera::FrameRateRange)", __qt_this)
        const QCamera::FrameRateRange& __qt_r21 = QtJambiAPI::valueReferenceFromNativeId<QCamera::FrameRateRange>(r21);
        __java_return_value = (*__qt_this) == __qt_r21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_setMaximumFrameRate_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble maximumFrameRate0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->maximumFrameRate = static_cast<qreal>(maximumFrameRate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_maximumFrameRate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->maximumFrameRate;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_setMinimumFrameRate_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble minimumFrameRate0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->minimumFrameRate = static_cast<qreal>(minimumFrameRate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_minimumFrameRate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->minimumFrameRate;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCamera_00024FrameRateRange_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCamera::FrameRateRange *__qt_this = QtJambiAPI::objectFromNativeId<QCamera::FrameRateRange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCamera_FrameRateRange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCamera::FrameRateRange>("QCamera::FrameRateRange", "io/qt/multimedia/QCamera$FrameRateRange");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCamera_FrameRateRange, {
        ConstructorInfo(&__qt_construct_QCamera_FrameRateRange, nullptr)
       ,ConstructorInfo(&__qt_construct_QCamera_FrameRateRange_cref_QCamera_FrameRateRange, "Lio/qt/multimedia/QCamera$FrameRateRange;")
       ,ConstructorInfo(&__qt_construct_QCamera_FrameRateRange_qreal_qreal, "DD")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCamera_FrameRateRange);
    registerMetaType<QCamera::FrameRateRange>("QCamera::FrameRateRange");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
